@@ -186,6 +186,7 @@ def do_get_templ(args):
         print("Replace project variable")
         variable_template = get_variable_template()
         process_code_template.process_code_template(args.saveto, namelist, variable_template)
+
     print("Done!")
     return 0
 
@@ -312,6 +313,42 @@ def do_compile(args):
     print(f"Compile successfully, save to {out}")
     return 0
 
+def do_tryload(args):
+
+    trtmodel = args.trtmodel
+    if not os.path.exists(trtmodel):
+        print(f"No such file {trtmodel}")
+        return 1
+
+    trtpy.init(args.cuda, args.trt)
+    print(f"Load tensorRT engine {trtmodel} ...")
+    trtpy.set_device(args.device)
+    engine = trtpy.load_infer_file(trtmodel)
+    if engine is None:
+        print(f"Engine load failed {trtmodel}")
+        return 1
+
+    engine.print()
+    print("Done!")
+    return 0
+
+def do_env_source(args):
+    trtpy.init(args.cuda, args.trt)
+    save = args.save
+    template_file = os.path.join(trtpy.trtpy_root, "environment-template.sh")
+    template_data = open(template_file, "r").read()
+    variable_template = get_variable_template()
+    template_data, _ = process_code_template.filter_content(template_data, variable_template)
+    
+    envbase_file = os.path.join(trtpy.nv_root, "env.sh")
+    open(envbase_file, "w").write(template_data)
+
+    if args.print:
+        print(envbase_file, end="")
+    else:
+        open(save, "w").write(template_data)
+        print(f"Save to {save}")
+
 if __name__ == "__main__":
     do_if_exec()
     parser = argparse.ArgumentParser()
@@ -364,6 +401,18 @@ if __name__ == "__main__":
     p.add_argument("--max-workspace-size", type=int, default=1<<30, help="max workspace size")
     p.add_argument("--cuda", type=str, help="cuda version, 10.2, 11.2, 10, 11 etc.", default=None)
     p.add_argument("--trt", type=str, help="trt version, 8.0, 8 etc.", default=None)
+
+    p = subp.add_parser("tryload", help="try to load trtmodel file")
+    p.add_argument("trtmodel", type=str, help="tensorRT engine file")
+    p.add_argument("--device", type=int, default=0, help="device id")
+    p.add_argument("--cuda", type=str, help="cuda version, 10.2, 11.2, 10, 11 etc.", default=None)
+    p.add_argument("--trt", type=str, help="trt version, 8.0, 8 etc.", default=None)
+
+    p = subp.add_parser("env-source", help="try to load trtmodel file")
+    p.add_argument("--save", type=str, default="trtpy-environment.sh", help="save to file")
+    p.add_argument("--print", action="store_true", help="print env path")
+    p.add_argument("--cuda", type=str, help="cuda version, 10.2, 11.2, 10, 11 etc.", default=None)
+    p.add_argument("--trt", type=str, help="trt version, 8.0, 8 etc.", default=None)
     args = parser.parse_args()
 
     cmd_funcs = {
@@ -376,7 +425,9 @@ if __name__ == "__main__":
         "local-cpp-pkg": do_local_cpp_pkg,
         "mnist-test":    do_mnist_test,
         "prep-vars":     do_prep_vars,
-        "compile":       do_compile
+        "compile":       do_compile,
+        "tryload":       do_tryload,
+        "env-source":    do_env_source
     }
 
     if args.cmd in cmd_funcs:
