@@ -29,12 +29,12 @@ namespace Yolo{
         FastGPU = 1      // Fast NMS with a small loss of accuracy in corner cases
     };
 
-    void image_to_tensor(const TRT::ImageBGR8U& image, shared_ptr<TRT::Tensor>& tensor, Type type, int ibatch);
+    void image_to_tensor(const TRT::Image& image, shared_ptr<TRT::Tensor>& tensor, Type type, int ibatch);
 
     class Infer{
     public:
-        virtual shared_future<BoxArray> commit(const TRT::ImageBGR8U& image) = 0;
-        virtual vector<shared_future<BoxArray>> commits(const vector<TRT::ImageBGR8U>& images) = 0;
+        virtual shared_future<BoxArray> commit(const TRT::Image& image) = 0;
+        virtual vector<shared_future<BoxArray>> commits(const vector<TRT::Image>& images) = 0;
     };
 
     shared_ptr<Infer> create_infer(
