@@ -4,9 +4,17 @@ import os
 include_list = ";.json;.cu;.cpp;.cuh;.h;.hpp;.cpp;makefile;cmakelists.txt;.sh;.bash;.py;.c;"
 
 def filter_content(content, variable_template):
+    found_variable = False
     for k, v in variable_template:
-        content = content.replace("${@" + k + "}", v)
-    return content
+        key = "${@" + k + "}"
+        if not found_variable:
+            if content.find(key) == -1:
+                continue
+            
+            found_variable = True
+
+        content = content.replace(key, v)
+    return content, found_variable
 
 
 def process_code_template(proj_dir, namelist, variable_template):
@@ -23,6 +31,8 @@ def process_code_template(proj_dir, namelist, variable_template):
             if not (include_list.find(";" + basename + ";") != -1 or suffix != "" and include_list.find(suffix) != -1):
                 continue
             
-            print(f"Process variables {full_path}")
             content = open(full_path, "r").read()
-            open(full_path, "w").write(filter_content(content, variable_template))
+            new_content, found_variable = filter_content(content, variable_template)
+            if found_variable:
+                print(f"Process variables {full_path}")
+                open(full_path, "w").write(new_content)
